# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Spinner(Component):
    """A Spinner component.
Render Bootstrap style loading spinners using only CSS.

This component can be used standalone to render a loading spinner, or it can
be used like `dash_core_components.Loading` by giving it children. In the
latter case the chosen spinner will display while the children are loading.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- color (string; optional):
    Sets the color of the Spinner. Main options are Bootstrap
    contextual colors: primary, secondary, success, info, warning,
    danger, light, dark, body, muted, white-50, black-50. You can also
    specify any valid CSS color of your choice (e.g. a hex code, a
    decimal code or a CSS color name)  If not specified will default
    to text colour.

- delay_hide (number; default 0):
    When using the spinner as a loading spinner, add a time delay (in
    ms) to the spinner being removed to prevent flickering.

- delay_show (number; default 0):
    When using the spinner as a loading spinner, add a time delay (in
    ms) to the spinner being shown after the loading_state is set to
    True.

- fullscreen (boolean; optional):
    Boolean that determines if the loading spinner will be displayed
    full-screen or not.

- fullscreenClassName (string; optional):
    **DEPRECATED** - use `fullscreen_class_name` instead.  Often used
    with CSS to style elements with common properties.

- fullscreen_class_name (string; optional):
    Often used with CSS to style elements with common properties.

- fullscreen_style (dict; optional):
    Defines CSS styles for the container when fullscreen=True.

- show_initially (boolean; default True):
    Whether the Spinner should show on app start-up before the loading
    state has been determined. Default True.

- size (string; optional):
    The spinner size. Options are 'sm', and 'md'.

- spinnerClassName (string; optional):
    **DEPRECATED** - use `spinner_class_name` instead.  CSS class
    names to apply to the spinner.

- spinner_class_name (string; optional):
    CSS class names to apply to the spinner.

- spinner_style (dict; optional):
    Inline CSS styles to apply to the spinner.

- type (string; default 'border'):
    The type of spinner. Options 'border' and 'grow'. Default
    'border'."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, fullscreen_style=Component.UNDEFINED, spinner_style=Component.UNDEFINED, fullscreen_class_name=Component.UNDEFINED, fullscreenClassName=Component.UNDEFINED, spinner_class_name=Component.UNDEFINED, spinnerClassName=Component.UNDEFINED, color=Component.UNDEFINED, type=Component.UNDEFINED, size=Component.UNDEFINED, fullscreen=Component.UNDEFINED, delay_hide=Component.UNDEFINED, delay_show=Component.UNDEFINED, show_initially=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'color', 'delay_hide', 'delay_show', 'fullscreen', 'fullscreenClassName', 'fullscreen_class_name', 'fullscreen_style', 'show_initially', 'size', 'spinnerClassName', 'spinner_class_name', 'spinner_style', 'type']
        self._type = 'Spinner'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'color', 'delay_hide', 'delay_show', 'fullscreen', 'fullscreenClassName', 'fullscreen_class_name', 'fullscreen_style', 'show_initially', 'size', 'spinnerClassName', 'spinner_class_name', 'spinner_style', 'type']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Spinner, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Navbar(Component):
    """A Navbar component.
The Navbar component can be used to make fully customisable navbars.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; default 'light'):
    Sets the color of the Navbar. Main options are primary, light and
    dark, default light.  You can also choose one of the other
    contextual classes provided by Bootstrap (secondary, success,
    warning, danger, info, white) or any valid CSS color of your
    choice (e.g. a hex code, a decimal code or a CSS color name).

- dark (boolean; optional):
    Applies the `navbar-dark` class to the Navbar, causing text in the
    children of the Navbar to use light colors for contrast /
    visibility.

- expand (boolean | string; default 'md'):
    Specify screen size at which to expand the menu bar, e.g. sm, md,
    lg etc.

- fixed (string; optional):
    Fix the navbar's position at the top or bottom of the page,
    options: top, bottom.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- light (boolean; default True):
    Applies the `navbar-light` class to the Navbar, causing text in
    the children of the Navbar to use dark colors for contrast /
    visibility.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- role (string; optional):
    The ARIA role attribute.

- sticky (a value equal to: 'top'; optional):
    Position the navbar at the top of the viewport, but only after
    scrolling past it. A convenience prop for the sticky-top
    positioning class. Not supported in <= IE11 and other older
    browsers  With `sticky`, the navbar remains in the viewport when
    you scroll. By contrast, with `fixed`, the navbar will remain at
    the top or bottom of the page.  sticky='top'.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- tag (string; optional):
    HTML tag to use for the Navbar, default 'nav'."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, light=Component.UNDEFINED, dark=Component.UNDEFINED, fixed=Component.UNDEFINED, sticky=Component.UNDEFINED, color=Component.UNDEFINED, role=Component.UNDEFINED, tag=Component.UNDEFINED, expand=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'className', 'class_name', 'color', 'dark', 'expand', 'fixed', 'key', 'light', 'loading_state', 'role', 'sticky', 'style', 'tag']
        self._type = 'Navbar'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'className', 'class_name', 'color', 'dark', 'expand', 'fixed', 'key', 'light', 'loading_state', 'role', 'sticky', 'style', 'tag']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Navbar, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Button(Component):
    """A Button component.
A component for creating Bootstrap buttons with different style options. The
Button component can act as a HTML button, link (<a>) or can be used like a
dash_core_components style `Link` for navigating between pages of a Dash app.

Use the `n_clicks` prop to trigger callbacks when the button has been
clicked.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- active (boolean; optional):
    Whether button is in active state. Default: False.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; optional):
    Button color, options: primary, secondary, success, info, warning,
    danger, link. Default: primary.

- disabled (boolean; optional):
    Disable button (make unclickable). Default: False.

- download (string; optional):
    Indicates that the hyperlink is to be used for downloading a
    resource.

- external_link (boolean; optional):
    If True, the browser will treat this as an external link, forcing
    a page refresh at the new location. If False, this just changes
    the location without triggering a page refresh. Use this if you
    are observing dcc.Location, for instance. Defaults to True for
    absolute URLs and False otherwise.

- href (string; optional):
    Pass a URL (relative or absolute) to make the menu entry a link.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- n_clicks (number; default 0):
    An integer that represents the number of times that this element
    has been clicked on.

- n_clicks_timestamp (number; default -1):
    Use of *_timestamp props has been deprecated in Dash in favour of
    dash.callback_context. See \"How do I determine which Input has
    changed?\" in the Dash FAQs https://dash.plot.ly/faqs.  An integer
    that represents the time (in ms since 1970) at which n_clicks
    changed. This can be used to tell which button was changed most
    recently.

- name (string; optional):
    The name of the button, submitted as a pair with the button’s
    value as part of the form data.

- outline (boolean; optional):
    Set outline button style, which removes background images and
    colors for a lightweight style.

- size (string; optional):
    Button size, options: 'lg', 'md', 'sm'.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- target (string; optional):
    Target attribute to pass on to link if using Button as an external
    link.

- title (string; optional):
    Sets the title attribute of the underlying HTML button.

- type (a value equal to: 'button', 'reset', 'submit'; optional):
    The default behavior of the button. Possible values are:
    \"button\", \"reset\", \"submit\". If left unspecified the default
    depends on usage: for buttons associated with a form (e.g. a
    dbc.Button inside a dbc.Form) the default is \"submit\". Otherwise
    the default is \"button\".

- value (string; optional):
    Defines the value associated with the button’s name when it’s
    submitted with the form data. This value is passed to the server
    in params when the form is submitted."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, key=Component.UNDEFINED, href=Component.UNDEFINED, external_link=Component.UNDEFINED, n_clicks=Component.UNDEFINED, n_clicks_timestamp=Component.UNDEFINED, active=Component.UNDEFINED, color=Component.UNDEFINED, disabled=Component.UNDEFINED, size=Component.UNDEFINED, title=Component.UNDEFINED, outline=Component.UNDEFINED, loading_state=Component.UNDEFINED, target=Component.UNDEFINED, type=Component.UNDEFINED, download=Component.UNDEFINED, name=Component.UNDEFINED, value=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'className', 'class_name', 'color', 'disabled', 'download', 'external_link', 'href', 'key', 'loading_state', 'n_clicks', 'n_clicks_timestamp', 'name', 'outline', 'size', 'style', 'target', 'title', 'type', 'value']
        self._type = 'Button'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'className', 'class_name', 'color', 'disabled', 'download', 'external_link', 'href', 'key', 'loading_state', 'n_clicks', 'n_clicks_timestamp', 'name', 'outline', 'size', 'style', 'target', 'title', 'type', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Button, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Accordion(Component):
    """An Accordion component.
A self contained Accordion component. Build up the children using the
AccordionItem component.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- active_item (string; optional):
    The item_id of the currently active item. If item_id has not been
    specified for the active item, this will default to item-i, where
    i is the index (starting from 0) of the item.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- flush (boolean; optional):
    Renders accordion edge-to-edge with its parent container.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- persisted_props (list of a value equal to: 'active_item's; default ['active_item']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- start_collapsed (boolean; default False):
    Set to True for all items to be collapsed initially.

- style (dict; optional):
    Defines CSS styles which will override styles previously set."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, flush=Component.UNDEFINED, active_item=Component.UNDEFINED, start_collapsed=Component.UNDEFINED, loading_state=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active_item', 'className', 'class_name', 'flush', 'key', 'loading_state', 'persisted_props', 'persistence', 'persistence_type', 'start_collapsed', 'style']
        self._type = 'Accordion'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active_item', 'className', 'class_name', 'flush', 'key', 'loading_state', 'persisted_props', 'persistence', 'persistence_type', 'start_collapsed', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Accordion, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Breadcrumb(Component):
    """A Breadcrumb component.
Use breadcrumbs to create a navigation breadcrumb in your app.

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- className (string; optional):
    **DEPRECATED** - Use class_name instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- itemClassName (string; optional):
    **DEPRECATED** - use item_class_name instead.  Class name ot apply
    to each item.

- item_class_name (string; optional):
    Class name to apply to each item.

- item_style (dict; optional):
    Defines inline CSS styles that will be added to each item in the
    breadcrumbs.

- items (list of dicts; optional):
    The details of the items to render inside of this component.

    `items` is a list of dicts with keys:

    - active (boolean; optional):
        Apply 'active' style to this component.

    - external_link (boolean; optional):
        If True, the browser will treat this as an external link,
        forcing a page refresh at the new location. If False, this
        just changes the location without triggering a page refresh.
        Use this if you are observing dcc.Location, for instance.
        Defaults to True for absolute URLs and False otherwise.

    - href (string; optional):
        URL of the resource to link to.

    - label (string; optional):
        Label to display inside the breadcrumbs.

    - target (string; optional):
        Target attribute to pass on to the link. Only applies to
        external links.

    - title (string; optional):
        title attribute for the inner a element.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- tag (dict; optional):
    HTML tag to use for the outer breadcrumb component. Default:
    \"nav\"."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, items=Component.UNDEFINED, style=Component.UNDEFINED, item_style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, item_class_name=Component.UNDEFINED, itemClassName=Component.UNDEFINED, key=Component.UNDEFINED, tag=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'class_name', 'itemClassName', 'item_class_name', 'item_style', 'items', 'key', 'loading_state', 'style', 'tag']
        self._type = 'Breadcrumb'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'class_name', 'itemClassName', 'item_class_name', 'item_style', 'items', 'key', 'loading_state', 'style', 'tag']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Breadcrumb, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Toast(Component):
    """A Toast component.
Toasts can be used to push messages and notifactions to users. Control
visibility of the toast with the `is_open` prop, or use `duration` to set a
timer for auto-dismissal.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- bodyClassName (string; optional):
    **DEPRECATED** - use `body_class_name` instead.  Often used with
    CSS to style elements with common properties. The classes
    specified with this prop will be applied to the body of the toast.

- body_class_name (string; optional):
    Often used with CSS to style elements with common properties. The
    classes specified with this prop will be applied to the body of
    the toast.

- body_style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the body of the toast.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; optional):
    Toast color, options: primary, secondary, success, info, warning,
    danger, light, dark. Default: secondary.

- dismissable (boolean; default False):
    Set to True to add a dismiss button to the header which will close
    the toast on click.

- duration (number; optional):
    Duration in milliseconds after which the Alert dismisses itself.

- header (string; optional):
    Text to populate the header with.

- headerClassName (string; optional):
    **DEPRECATED** - use `header_class_name` instead  Often used with
    CSS to style elements with common properties. The classes
    specified with this prop will be applied to the header of the
    toast.

- header_class_name (string; optional):
    Often used with CSS to style elements with common properties. The
    classes specified with this prop will be applied to the header of
    the toast.

- header_style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the header of the toast.

- icon (string; optional):
    Add a contextually coloured icon to the header of the toast.
    Options are: \"primary\", \"secondary\", \"success\", \"warning\",
    \"danger\", \"info\", \"light\" or \"dark\".

- is_open (boolean; default True):
    Whether Toast is currently open.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- n_dismiss (number; default 0):
    An integer that represents the number of times that the dismiss
    button has been clicked on.

- n_dismiss_timestamp (number; default -1):
    Use of *_timestamp props has been deprecated in Dash in favour of
    dash.callback_context. See \"How do I determine which Input has
    changed?\" in the Dash FAQs https://dash.plot.ly/faqs.  An integer
    that represents the time (in ms since 1970) at which n_dismiss
    changed. This can be used to tell which button was changed most
    recently.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- tag (string; optional):
    HTML tag to use for the Toast, default: div."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, header_style=Component.UNDEFINED, header_class_name=Component.UNDEFINED, headerClassName=Component.UNDEFINED, body_style=Component.UNDEFINED, body_class_name=Component.UNDEFINED, bodyClassName=Component.UNDEFINED, tag=Component.UNDEFINED, is_open=Component.UNDEFINED, key=Component.UNDEFINED, header=Component.UNDEFINED, dismissable=Component.UNDEFINED, duration=Component.UNDEFINED, n_dismiss=Component.UNDEFINED, n_dismiss_timestamp=Component.UNDEFINED, icon=Component.UNDEFINED, color=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'bodyClassName', 'body_class_name', 'body_style', 'className', 'class_name', 'color', 'dismissable', 'duration', 'header', 'headerClassName', 'header_class_name', 'header_style', 'icon', 'is_open', 'key', 'loading_state', 'n_dismiss', 'n_dismiss_timestamp', 'style', 'tag']
        self._type = 'Toast'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'bodyClassName', 'body_class_name', 'body_style', 'className', 'class_name', 'color', 'dismissable', 'duration', 'header', 'headerClassName', 'header_class_name', 'header_style', 'icon', 'is_open', 'key', 'loading_state', 'n_dismiss', 'n_dismiss_timestamp', 'style', 'tag']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Toast, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Offcanvas(Component):
    """An Offcanvas component.
Create a toggleable hidden sidebar using the Offcanvas component.
Toggle the visibility with the `is_open` prop.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- autoFocus (boolean; optional):
    **DEPRECATED** Use `autofocus` instead          Puts the focus on
    the modal when initialized.

- autofocus (boolean; optional):
    Puts the focus on the offcanvas when initialized.

- backdrop (boolean | a value equal to: 'static'; default True):
    Includes an offcanvas-backdrop element. Alternatively, specify
    'static' for a backdrop which doesn't close the modal on click.

- backdropClassName (string; optional):
    **DEPRECATED** - Use backdrop_class_name instead.  CSS class to
    apply to the backdrop.

- backdrop_class_name (string; optional):
    CSS class to apply to the backdrop.

- className (string; optional):
    **DEPRECATED** - Use class_name instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- close_button (boolean; default True):
    Specify whether the Component should contain a close button in the
    header.

- is_open (boolean; default False):
    Whether offcanvas is currently open.

- keyboard (boolean; optional):
    Close the offcanvas when escape key is pressed.

- labelledBy (string; optional):
    **DEPRECATED** Use `labelledby` instead  The ARIA labelledby
    attribute.

- labelledby (string; optional):
    The ARIA labelledby attribute.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- placement (a value equal to: 'start', 'end', 'top', 'bottom'; optional):
    Which side of the viewport the offcanvas will appear from.

- scrollable (boolean; optional):
    Allow body scrolling while offcanvas is open.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- title (string; optional):
    The header title."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, labelledby=Component.UNDEFINED, labelledBy=Component.UNDEFINED, backdrop=Component.UNDEFINED, backdrop_class_name=Component.UNDEFINED, backdropClassName=Component.UNDEFINED, keyboard=Component.UNDEFINED, is_open=Component.UNDEFINED, placement=Component.UNDEFINED, scrollable=Component.UNDEFINED, autofocus=Component.UNDEFINED, autoFocus=Component.UNDEFINED, title=Component.UNDEFINED, close_button=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'autoFocus', 'autofocus', 'backdrop', 'backdropClassName', 'backdrop_class_name', 'className', 'class_name', 'close_button', 'is_open', 'keyboard', 'labelledBy', 'labelledby', 'loading_state', 'placement', 'scrollable', 'style', 'title']
        self._type = 'Offcanvas'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'autoFocus', 'autofocus', 'backdrop', 'backdropClassName', 'backdrop_class_name', 'className', 'class_name', 'close_button', 'is_open', 'keyboard', 'labelledBy', 'labelledby', 'loading_state', 'placement', 'scrollable', 'style', 'title']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Offcanvas, self).__init__(children=children, **args)



from functools import reduce
from itertools import groupby
from operator import add

from dash import html


def _generate_table_from_df(
    cls,
    df,
    float_format=None,
    columns=None,
    header=True,
    index=False,
    index_label=None,
    date_format=None,
    **table_kwargs
):
    """
    Generate a Table component from a dataframe.

    Parameters
    ----------
    df : pandas.DataFrame
        DataFrame to render as a table.
    float_format : str, optional
        Format to use for floating point numbers.
    columns : sequence, optional
        Columns to render.
    header : boolean or list(str) or dict(str: str), optional
        Write out the column names. If a list of strings is given it is assumed
        to be aliases for the columns names (and hence must be the same length
        as df.columns). A dict can be passed to rename some columns, the format
        is {'<current_name>': '<new_name>'}. The dictionary need not have an
        entry for every column.
    index : boolean, optional
        Render the row names (index).
    index_label : str, optional
        Column label for index column if desired. If None is passed, but both
        header and index are True, then the index name is used.
    date_format : str, optional
        Format string for datetime objects.
    **table_kwargs : Keyword arguments
        Additional arguments to pass to the table component. See
        dash_bootstrap_components.Table for details.
    """
    import numpy as np
    import pandas as pd

    if columns is not None:
        df = df.loc[:, columns]

    if float_format is not None:
        for c in df.select_dtypes(["float"]).columns:
            df[c] = df[c].map(lambda x: "{1:{0}}".format(float_format, x))

    if date_format is not None:
        for c in df.select_dtypes(["datetime"]).columns:
            df[c] = df[c].map(lambda x: x.strftime(date_format))

    if index:
        df = df.reset_index()
        if index_label is not None:
            df = df.rename(columns={"index": index_label})

    if header:
        if isinstance(header, (tuple, list, np.ndarray, pd.Index)):
            try:
                df.columns = header
            except ValueError:
                raise ValueError(
                    "If specifying column names with a sequence, the number "
                    "of names must exactly match the number of columns."
                )
        elif isinstance(header, dict):
            df = df.rename(columns=header)

        # Get the actual headers
        n_levels = df.columns.nlevels
        header_values = [
            list(df.columns.get_level_values(level))
            for level in range(n_levels)
        ]

        # The sizes of consecutive header groups at each level
        header_spans = [
            [len(list(group)) for _, group in groupby(level_values)]
            for level_values in header_values
        ]

        # The positions of header changes for each level as an integer
        header_breaks = [
            [sum(level_spans[:i]) for i in range(1, len(level_spans) + 1)]
            for level_spans in header_spans
        ]

        # Include breaks from higher levels
        header_breaks = [
            sorted(set(reduce(add, header_breaks[:level])).union({0}))
            for level in range(1, n_levels + 1)
        ]

        # Go from header break positions back to cell spans
        header_spans = [
            reversed(
                [
                    level_breaks[i] - level_breaks[i - 1]
                    for i in range(len(level_breaks) - 1, 0, -1)
                ]
            )
            for level_breaks in header_breaks
        ]

        table = [
            html.Thead(
                [
                    html.Tr(
                        children=[
                            html.Th(
                                header_values[level][pos],
                                colSpan=span,
                            )
                            for pos, span in zip(
                                header_breaks[level], header_spans[level]
                            )
                        ]
                    )
                    for level in range(n_levels)
                ]
            )
        ]
    else:
        table = []
    table.append(
        html.Tbody(
            [
                html.Tr(
                    [html.Td(df.iloc[i, j]) for j in range(len(df.columns))]
                )
                for i in range(len(df))
            ]
        )
    )
    return cls(table, **table_kwargs)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Modal(Component):
    """A Modal component.
Create a toggleable dialog using the Modal component. Toggle the visibility
with the `is_open` prop.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- autoFocus (boolean; optional):
    **DEPRECATED** Use `autofocus` instead          Puts the focus on
    the modal when initialized.

- autofocus (boolean; optional):
    Puts the focus on the modal when initialized.

- backdrop (boolean | a value equal to: 'static'; optional):
    Includes a modal-backdrop element. Alternatively, specify 'static'
    for a backdrop which doesn't close the modal on click.

- backdropClassName (string; optional):
    **DEPRECATED** Use `backdrop_class_name` instead  CSS class to
    apply to the backdrop.

- backdrop_class_name (string; optional):
    CSS class to apply to the backdrop.

- centered (boolean; optional):
    If True, vertically center modal on page.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- contentClassName (string; optional):
    **DEPRECATED** Use `content_class_name` instead  CSS class to
    apply to the modal content.

- content_class_name (string; optional):
    CSS class to apply to the modal content.

- fade (boolean; optional):
    Set to False for a modal that simply appears rather than fades
    into view.

- fullscreen (a value equal to: PropTypes.bool, PropTypes.oneOf(['sm-down', 'md-down', 'lg-down', 'xl-down', 'xxl-down']); optional):
    Renders a fullscreen modal. Specifying a breakpoint will render
    the modal as fullscreen below the breakpoint size.

- is_open (boolean; optional):
    Whether modal is currently open.

- keyboard (boolean; optional):
    Close the modal when escape key is pressed.

- labelledBy (string; optional):
    **DEPRECATED** Use `labelledby` instead  The ARIA labelledby
    attribute.

- labelledby (string; optional):
    The ARIA labelledby attribute.

- modalClassName (string; optional):
    **DEPRECATED** Use `modal_class_name` instead  CSS class to apply
    to the modal.

- modal_class_name (string; optional):
    CSS class to apply to the modal.

- role (string; optional):
    The ARIA role attribute.

- scrollable (boolean; optional):
    It True, scroll the modal body rather than the entire modal when
    it is too long to all fit on the screen.

- size (string; optional):
    Set the size of the modal. Options sm, lg, xl for small, large or
    extra large sized modals, or leave undefined for default size.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- tag (string; optional):
    HTML tag to use for the Modal, default: div.

- zIndex (number | string; optional):
    **DEPRECATED** Use `zindex` instead  Set the z-index of the modal.
    Default 1050.

- zindex (number | string; optional):
    Set the z-index of the modal. Default 1050."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, tag=Component.UNDEFINED, is_open=Component.UNDEFINED, centered=Component.UNDEFINED, scrollable=Component.UNDEFINED, autofocus=Component.UNDEFINED, autoFocus=Component.UNDEFINED, size=Component.UNDEFINED, role=Component.UNDEFINED, labelledby=Component.UNDEFINED, labelledBy=Component.UNDEFINED, keyboard=Component.UNDEFINED, backdrop=Component.UNDEFINED, modal_class_name=Component.UNDEFINED, modalClassName=Component.UNDEFINED, backdrop_class_name=Component.UNDEFINED, backdropClassName=Component.UNDEFINED, content_class_name=Component.UNDEFINED, contentClassName=Component.UNDEFINED, fade=Component.UNDEFINED, fullscreen=Component.UNDEFINED, zindex=Component.UNDEFINED, zIndex=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'autoFocus', 'autofocus', 'backdrop', 'backdropClassName', 'backdrop_class_name', 'centered', 'className', 'class_name', 'contentClassName', 'content_class_name', 'fade', 'fullscreen', 'is_open', 'keyboard', 'labelledBy', 'labelledby', 'modalClassName', 'modal_class_name', 'role', 'scrollable', 'size', 'style', 'tag', 'zIndex', 'zindex']
        self._type = 'Modal'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'autoFocus', 'autofocus', 'backdrop', 'backdropClassName', 'backdrop_class_name', 'centered', 'className', 'class_name', 'contentClassName', 'content_class_name', 'fade', 'fullscreen', 'is_open', 'keyboard', 'labelledBy', 'labelledby', 'modalClassName', 'modal_class_name', 'role', 'scrollable', 'size', 'style', 'tag', 'zIndex', 'zindex']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Modal, self).__init__(children=children, **args)



BOOTSTRAP = (
    "https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css"
)

GRID = "https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap-grid.min.css"  # noqa

_BOOTSWATCH_BASE = "https://cdn.jsdelivr.net/npm/bootswatch@5.1.3/dist/"

CERULEAN = _BOOTSWATCH_BASE + "cerulean/bootstrap.min.css"
COSMO = _BOOTSWATCH_BASE + "cosmo/bootstrap.min.css"
CYBORG = _BOOTSWATCH_BASE + "cyborg/bootstrap.min.css"
DARKLY = _BOOTSWATCH_BASE + "darkly/bootstrap.min.css"
FLATLY = _BOOTSWATCH_BASE + "flatly/bootstrap.min.css"
JOURNAL = _BOOTSWATCH_BASE + "journal/bootstrap.min.css"
LITERA = _BOOTSWATCH_BASE + "litera/bootstrap.min.css"
LUMEN = _BOOTSWATCH_BASE + "lumen/bootstrap.min.css"
LUX = _BOOTSWATCH_BASE + "lux/bootstrap.min.css"
MATERIA = _BOOTSWATCH_BASE + "materia/bootstrap.min.css"
MINTY = _BOOTSWATCH_BASE + "minty/bootstrap.min.css"
MORPH = _BOOTSWATCH_BASE + "morph/bootstrap.min.css"
PULSE = _BOOTSWATCH_BASE + "pulse/bootstrap.min.css"
QUARTZ = _BOOTSWATCH_BASE + "quartz/bootstrap.min.css"
SANDSTONE = _BOOTSWATCH_BASE + "sandstone/bootstrap.min.css"
SIMPLEX = _BOOTSWATCH_BASE + "simplex/bootstrap.min.css"
SKETCHY = _BOOTSWATCH_BASE + "sketchy/bootstrap.min.css"
SLATE = _BOOTSWATCH_BASE + "slate/bootstrap.min.css"
SOLAR = _BOOTSWATCH_BASE + "solar/bootstrap.min.css"
SPACELAB = _BOOTSWATCH_BASE + "spacelab/bootstrap.min.css"
SUPERHERO = _BOOTSWATCH_BASE + "superhero/bootstrap.min.css"
UNITED = _BOOTSWATCH_BASE + "united/bootstrap.min.css"
VAPOR = _BOOTSWATCH_BASE + "vapor/bootstrap.min.css"
YETI = _BOOTSWATCH_BASE + "yeti/bootstrap.min.css"
ZEPHYR = _BOOTSWATCH_BASE + "zephyr/bootstrap.min.css"



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Progress(Component):
    """A Progress component.


Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component. Use this to nest progress bars.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- animated (boolean; optional):
    Animate the bar, must have striped set to True to work.

- bar (boolean; optional):
    Set to True when nesting Progress inside another Progress
    component to create a multi-progress bar.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; optional):
    Set color of the progress bar, options: primary, secondary,
    success, warning, danger, info or any valid CSS color of your
    choice (e.g. a hex code, a decimal code or a CSS color name).

- hide_label (boolean; default False):
    Set to True to hide the label.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- label (string; optional):
    Adds a label to the progress bar.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- max (number; optional):
    Upper limit for value, default: 100.

- min (number; optional):
    Lower limit for value, default: 0.

- striped (boolean; optional):
    Use striped progress bar.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- value (string | number; optional):
    Specify progress, value from min to max inclusive."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, bar=Component.UNDEFINED, min=Component.UNDEFINED, max=Component.UNDEFINED, value=Component.UNDEFINED, label=Component.UNDEFINED, hide_label=Component.UNDEFINED, animated=Component.UNDEFINED, striped=Component.UNDEFINED, color=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'animated', 'bar', 'className', 'class_name', 'color', 'hide_label', 'key', 'label', 'loading_state', 'max', 'min', 'striped', 'style', 'value']
        self._type = 'Progress'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'animated', 'bar', 'className', 'class_name', 'color', 'hide_label', 'key', 'label', 'loading_state', 'max', 'min', 'striped', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Progress, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class NavLink(Component):
    """A NavLink component.
Add a link to a `Nav`. Can be used as a child of `NavItem` or of `Nav`
directly.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- active (boolean | a value equal to: 'partial', 'exact'; default False):
    Apply 'active' style to this component. Set to \"exact\" to
    automatically toggle active status when the current pathname
    matches href, or to \"partial\" to automatically toggle on a
    partial match. Assumes that href is a relative url such as /link
    rather than an absolute such as https://example.com/link  For
    example - dbc.NavLink(..., href=\"/my-page\", active=\"exact\")
    will be active on   \"/my-page\" but not \"/my-page/other\" or
    \"/random\" - dbc.NavLink(..., href=\"/my-page\",
    active=\"partial\") will be active on   \"/my-page\" and
    \"/my-page/other\" but not \"/random\".

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- disabled (boolean; default False):
    Disable the link.

- external_link (boolean; optional):
    If True, the browser will treat this as an external link, forcing
    a page refresh at the new location. If False, this just changes
    the location without triggering a page refresh. Use this if you
    are observing dcc.Location, for instance. Defaults to True for
    absolute URLs and False otherwise.

- href (string; optional):
    The URL of the linked resource.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- n_clicks (number; default 0):
    An integer that represents the number of times that this element
    has been clicked on.

- n_clicks_timestamp (number; default -1):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- target (string; optional):
    Target attribute to pass on to the link. Only applies to external
    links."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, href=Component.UNDEFINED, active=Component.UNDEFINED, disabled=Component.UNDEFINED, external_link=Component.UNDEFINED, n_clicks=Component.UNDEFINED, n_clicks_timestamp=Component.UNDEFINED, loading_state=Component.UNDEFINED, target=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'active', 'className', 'class_name', 'disabled', 'external_link', 'href', 'key', 'loading_state', 'n_clicks', 'n_clicks_timestamp', 'style', 'target']
        self._type = 'NavLink'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'active', 'className', 'class_name', 'disabled', 'external_link', 'href', 'key', 'loading_state', 'n_clicks', 'n_clicks_timestamp', 'style', 'target']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(NavLink, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class RadioButton(Component):
    """A RadioButton component.
Checklist is a component that encapsulates several checkboxes.
The values and labels of the checklist is specified in the `options`
property and the checked items are specified with the `value` property.
Each checkbox is rendered as an input / label pair. `Checklist` must be
given an `id` to work properly.

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  The class of the
    container (div).

- class_name (string; optional):
    The class of the container (div).

- disabled (boolean; default False):
    Disable the RadioButton.

- inputClassName (string; default ''):
    **DEPRECATED** Use `input_class_name` instead.  The class of the
    <input> checkbox element.

- inputStyle (dict; optional):
    **DEPRECATED** Use `input_style` instead.  The style of the
    <input> checkbox element.

- input_class_name (string; default ''):
    The class of the <input> checkbox element.

- input_style (dict; optional):
    The style of the <input> checkbox element.

- label (string; optional):
    The label of the <input> element.

- labelClassName (string; default ''):
    **DEPRECATED** Use `label_class_name` instead.  CSS classes to
    apply to the <label> element for each item.

- labelStyle (dict; optional):
    **DEPRECATED** Use `label_style` instead.  Inline style arguments
    to apply to the <label> element for each item.

- label_class_name (string; default ''):
    CSS classes to apply to the <label> element for each item.

- label_id (string; optional):
    The id of the label.

- label_style (dict; optional):
    Inline style arguments to apply to the <label> element for each
    item.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- name (string; optional):
    The name of the control, which is submitted with the form data.

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- style (dict; optional):
    The style of the container (div).

- value (boolean; default False):
    The value of the input."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, input_style=Component.UNDEFINED, inputStyle=Component.UNDEFINED, input_class_name=Component.UNDEFINED, inputClassName=Component.UNDEFINED, label=Component.UNDEFINED, label_id=Component.UNDEFINED, label_style=Component.UNDEFINED, labelStyle=Component.UNDEFINED, label_class_name=Component.UNDEFINED, labelClassName=Component.UNDEFINED, name=Component.UNDEFINED, value=Component.UNDEFINED, disabled=Component.UNDEFINED, loading_state=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'class_name', 'disabled', 'inputClassName', 'inputStyle', 'input_class_name', 'input_style', 'label', 'labelClassName', 'labelStyle', 'label_class_name', 'label_id', 'label_style', 'loading_state', 'name', 'persisted_props', 'persistence', 'persistence_type', 'style', 'value']
        self._type = 'RadioButton'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'class_name', 'disabled', 'inputClassName', 'inputStyle', 'input_class_name', 'input_style', 'label', 'labelClassName', 'labelStyle', 'label_class_name', 'label_id', 'label_style', 'loading_state', 'name', 'persisted_props', 'persistence', 'persistence_type', 'style', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(RadioButton, self).__init__(**args)



from .Accordion import Accordion
from .AccordionItem import AccordionItem
from .Alert import Alert
from .Badge import Badge
from .Breadcrumb import Breadcrumb
from .Button import Button
from .ButtonGroup import ButtonGroup
from .Card import Card
from .CardBody import CardBody
from .CardFooter import CardFooter
from .CardGroup import CardGroup
from .CardHeader import CardHeader
from .CardImg import CardImg
from .CardImgOverlay import CardImgOverlay
from .CardLink import CardLink
from .Carousel import Carousel
from .Collapse import Collapse
from .DropdownMenu import DropdownMenu
from .DropdownMenuItem import DropdownMenuItem
from .Fade import Fade
from .Form import Form
from .FormFeedback import FormFeedback
from .FormFloating import FormFloating
from .FormText import FormText
from .Label import Label
from .Checkbox import Checkbox
from .Checklist import Checklist
from .Input import Input
from .InputGroup import InputGroup
from .InputGroupText import InputGroupText
from .RadioButton import RadioButton
from .RadioItems import RadioItems
from .Select import Select
from .Switch import Switch
from .Textarea import Textarea
from .Col import Col
from .Container import Container
from .Row import Row
from .ListGroup import ListGroup
from .ListGroupItem import ListGroupItem
from .Modal import Modal
from .ModalBody import ModalBody
from .ModalFooter import ModalFooter
from .ModalHeader import ModalHeader
from .ModalTitle import ModalTitle
from .Nav import Nav
from .NavItem import NavItem
from .NavLink import NavLink
from .Navbar import Navbar
from .NavbarBrand import NavbarBrand
from .NavbarSimple import NavbarSimple
from .NavbarToggler import NavbarToggler
from .Offcanvas import Offcanvas
from .Pagination import Pagination
from .Popover import Popover
from .PopoverBody import PopoverBody
from .PopoverHeader import PopoverHeader
from .Progress import Progress
from .Spinner import Spinner
from .Table import Table
from .Tab import Tab
from .Tabs import Tabs
from .Toast import Toast
from .Tooltip import Tooltip

__all__ = [
    "Accordion",
    "AccordionItem",
    "Alert",
    "Badge",
    "Breadcrumb",
    "Button",
    "ButtonGroup",
    "Card",
    "CardBody",
    "CardFooter",
    "CardGroup",
    "CardHeader",
    "CardImg",
    "CardImgOverlay",
    "CardLink",
    "Carousel",
    "Collapse",
    "DropdownMenu",
    "DropdownMenuItem",
    "Fade",
    "Form",
    "FormFeedback",
    "FormFloating",
    "FormText",
    "Label",
    "Checkbox",
    "Checklist",
    "Input",
    "InputGroup",
    "InputGroupText",
    "RadioButton",
    "RadioItems",
    "Select",
    "Switch",
    "Textarea",
    "Col",
    "Container",
    "Row",
    "ListGroup",
    "ListGroupItem",
    "Modal",
    "ModalBody",
    "ModalFooter",
    "ModalHeader",
    "ModalTitle",
    "Nav",
    "NavItem",
    "NavLink",
    "Navbar",
    "NavbarBrand",
    "NavbarSimple",
    "NavbarToggler",
    "Offcanvas",
    "Pagination",
    "Popover",
    "PopoverBody",
    "PopoverHeader",
    "Progress",
    "Spinner",
    "Table",
    "Tab",
    "Tabs",
    "Toast",
    "Tooltip"
]


# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Tab(Component):
    """A Tab component.
Create a single tab. Should be used as a component of Tabs.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- activeLabelClassName (string; optional):
    **DEPRECATED** Use `active_label_class_name` instead  Often used
    with CSS to style elements with common properties. The classes
    specified with this prop will be applied to the NavLink in the tab
    when it is active.

- activeTabClassName (string; optional):
    **DEPRECATED** Use `active_tab_class_name` instead  Often used
    with CSS to style elements with common properties. The classes
    specified with this prop will be applied to the NavItem in the tab
    when it is active.

- active_label_class_name (string; optional):
    Often used with CSS to style elements with common properties. The
    classes specified with this prop will be applied to the NavLink in
    the tab when it is active.

- active_label_style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the NavLink in the tab when it is active.

- active_tab_class_name (string; optional):
    Often used with CSS to style elements with common properties. The
    classes specified with this prop will be applied to the NavItem in
    the tab when it is active.

- active_tab_style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the NavItem in the tab when it is active.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- disabled (boolean; default False):
    Determines if tab is disabled or not - defaults to False.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- label (string; optional):
    The tab's label, displayed in the tab itself.

- labelClassName (string; optional):
    **DEPRECATED** Use `label_class_name` instead  Often used with CSS
    to style elements with common properties. The classes specified
    with this prop will be applied to the NavLink in the tab.

- label_class_name (string; optional):
    Often used with CSS to style elements with common properties. The
    classes specified with this prop will be applied to the NavLink in
    the tab.

- label_style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the NavLink in the tab.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the content of the Tab.

- tabClassName (string; optional):
    **DEPRECATED** Use `tab_class_name` instead  Often used with CSS
    to style elements with common properties. The classes specified
    with this prop will be applied to the NavItem in the tab.

- tab_class_name (string; optional):
    Often used with CSS to style elements with common properties. The
    classes specified with this prop will be applied to the NavItem in
    the tab.

- tab_id (string; optional):
    Optional identifier for tab used for determining which tab is
    visible if not specified, and Tab is being used inside Tabs
    component, the tabId will be set to \"tab-i\" where i is (zero
    indexed) position of tab in list tabs pased to Tabs component.

- tab_style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the NavItem in the tab."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, tab_style=Component.UNDEFINED, active_tab_style=Component.UNDEFINED, label_style=Component.UNDEFINED, active_label_style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, tab_class_name=Component.UNDEFINED, tabClassName=Component.UNDEFINED, active_tab_class_name=Component.UNDEFINED, activeTabClassName=Component.UNDEFINED, label_class_name=Component.UNDEFINED, labelClassName=Component.UNDEFINED, active_label_class_name=Component.UNDEFINED, activeLabelClassName=Component.UNDEFINED, key=Component.UNDEFINED, label=Component.UNDEFINED, tab_id=Component.UNDEFINED, disabled=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'activeLabelClassName', 'activeTabClassName', 'active_label_class_name', 'active_label_style', 'active_tab_class_name', 'active_tab_style', 'className', 'class_name', 'disabled', 'key', 'label', 'labelClassName', 'label_class_name', 'label_style', 'loading_state', 'style', 'tabClassName', 'tab_class_name', 'tab_id', 'tab_style']
        self._type = 'Tab'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'activeLabelClassName', 'activeTabClassName', 'active_label_class_name', 'active_label_style', 'active_tab_class_name', 'active_tab_style', 'className', 'class_name', 'disabled', 'key', 'label', 'labelClassName', 'label_class_name', 'label_style', 'loading_state', 'style', 'tabClassName', 'tab_class_name', 'tab_id', 'tab_style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Tab, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Table(Component):
    """A Table component.
A component for applying Bootstrap styles to HTML tables. Use this as a
drop-in replacement for `html.Table`, or generate a table from a Pandas
DataFrame using `dbc.Table.from_dataframe`.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- bordered (boolean; optional):
    Apply the `table-bordered` class which adds borders on all sides
    of the table and cells.

- borderless (boolean; optional):
    Apply the `table-borderless` class which removes all borders from
    the table and cells.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; optional):
    Table color, options: primary, secondary, success, info, warning,
    danger, dark, light. Default: secondary.

- dark (boolean; optional):
    **DEPRECATED** - Use color=\"dark\" instead.  Apply the
    `table-dark` class for dark cell backgrounds and light text.

- hover (boolean; optional):
    Apply the `table-hover` class which enables a hover state on table
    rows within the table body.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- responsive (boolean | string; optional):
    Set to True or one of the breakpoints 'sm', 'md', 'lg', 'xl' to
    make table scroll horizontally at lower breakpoints.

- size (string; optional):
    Specify table size, options: 'sm', 'md', 'lg'.

- striped (boolean; optional):
    Apply the `table-striped` class which applies 'zebra striping' to
    rows in the table body.

- style (dict; optional):
    Defines CSS styles which will override styles previously set."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, size=Component.UNDEFINED, bordered=Component.UNDEFINED, borderless=Component.UNDEFINED, striped=Component.UNDEFINED, color=Component.UNDEFINED, dark=Component.UNDEFINED, hover=Component.UNDEFINED, responsive=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'bordered', 'borderless', 'className', 'class_name', 'color', 'dark', 'hover', 'key', 'loading_state', 'responsive', 'size', 'striped', 'style']
        self._type = 'Table'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'bordered', 'borderless', 'className', 'class_name', 'color', 'dark', 'hover', 'key', 'loading_state', 'responsive', 'size', 'striped', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Table, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Card(Component):
    """A Card component.
Component for creating Bootstrap cards. Use in conjunction with CardBody,
CardImg, CardLink, CardHeader and CardFooter. Can also be used in
conjunction with CardColumns, CardDeck, CardGroup for different layout
options.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- body (boolean; optional):
    Apply the `card-body` class to the card, so that there is no need
    to also include a CardBody component in the children of this Card.
    Default: False.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; optional):
    Card color, options: primary, secondary, success, info, warning,
    danger, light, dark or any valid CSS color of your choice (e.g. a
    hex code, a decimal code or a CSS color name). Default is light.

- inverse (boolean; optional):
    Invert text colours for use with a darker background.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- outline (boolean; optional):
    Apply color styling to just the border of the card.

- style (dict; optional):
    Defines CSS styles which will override styles previously set."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, color=Component.UNDEFINED, body=Component.UNDEFINED, outline=Component.UNDEFINED, inverse=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'body', 'className', 'class_name', 'color', 'inverse', 'key', 'loading_state', 'outline', 'style']
        self._type = 'Card'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'body', 'className', 'class_name', 'color', 'inverse', 'key', 'loading_state', 'outline', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Card, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Textarea(Component):
    """A Textarea component.
A basic HTML textarea for entering multiline text based on the corresponding
component in dash-core-components

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- accessKey (string; optional):
    **DEPRECATED** Use `accesskey` instead  Defines a keyboard
    shortcut to activate or add focus to the element.

- accesskey (string; optional):
    Defines a keyboard shortcut to activate or add focus to the
    element.

- autoFocus (string; optional):
    **DEPRECATED** Use `autofocus` instead  The element should be
    automatically focused after the page loaded.

- autofocus (string; optional):
    The element should be automatically focused after the page loaded.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- cols (string | number; optional):
    Defines the number of columns in a textarea.

- contentEditable (string | number; optional):
    **DEPRECATED** Use `contenteditable` instead  Indicates whether
    the element's content is editable.

- contenteditable (string | number; optional):
    Indicates whether the element's content is editable.

- contextMenu (string; optional):
    **DEPRECATED** Use `contextmenu` instead  Defines the ID of a
    <menu> element which will serve as the element's context menu.

- contextmenu (string; optional):
    Defines the ID of a <menu> element which will serve as the
    element's context menu.

- debounce (boolean; default False):
    If True, changes to input will be sent back to the Dash server
    only on enter or when losing focus. If it's False, it will sent
    the value back on every change.

- dir (string; optional):
    Defines the text direction. Allowed values are ltr (Left-To-Right)
    or rtl (Right-To-Left).

- disabled (string | boolean; optional):
    Indicates whether the user can interact with the element.

- draggable (a value equal to: 'true', 'false' | boolean; optional):
    Defines whether the element can be dragged.

- form (string; optional):
    Indicates the form that is the owner of the element.

- hidden (string; optional):
    Prevents rendering of given element, while keeping child elements,
    e.g. script elements, active.

- invalid (boolean; optional):
    Apply invalid style to the Textarea for feedback purposes. This
    will cause any FormFeedback in the enclosing div with valid=False
    to display.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- lang (string; optional):
    Defines the language used in the element.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- maxLength (string | number; optional):
    **DEPRECATED** Use `maxlength` instead  Defines the maximum number
    of characters allowed in the element.

- maxlength (string | number; optional):
    Defines the maximum number of characters allowed in the element.

- minLength (string | number; optional):
    **DEPRECATED** Use `minlength` instead  Defines the minimum number
    of characters allowed in the element.

- minlength (string | number; optional):
    Defines the minimum number of characters allowed in the element.

- n_blur (number; default 0):
    Number of times the input lost focus.

- n_blur_timestamp (number; default -1):
    Last time the input lost focus.

- n_clicks (number; default 0):
    An integer that represents the number of times that this element
    has been clicked on.

- n_clicks_timestamp (number; default -1):
    An integer that represents the time (in ms since 1970) at which
    n_clicks changed. This can be used to tell which button was
    changed most recently.

- n_submit (number; default 0):
    Number of times the `Enter` key was pressed while the textarea had
    focus.

- n_submit_timestamp (number; default -1):
    Last time that `Enter` was pressed.

- name (string; optional):
    Name of the element. For example used by the server to identify
    the fields in form submits.

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- placeholder (string; optional):
    Provides a hint to the user of what can be entered in the field.

- readOnly (boolean | a value equal to: 'readOnly', 'readonly', 'READONLY'; optional):
    **DEPRECATED** Use `readonly` instead  Indicates whether the
    element can be edited.

- readonly (boolean | a value equal to: 'readOnly', 'readonly', 'READONLY'; optional):
    Indicates whether the element can be edited.

- required (a value equal to: 'required', 'REQUIRED' | boolean; optional):
    This attribute specifies that the user must fill in a value before
    submitting a form. It cannot be used when the type attribute is
    hidden, image, or a button type (submit, reset, or button). The
    :optional and :required CSS pseudo-classes will be applied to the
    field as appropriate. required is an HTML boolean attribute - it
    is enabled by a boolean or 'required'. Alternative capitalizations
    `REQUIRED` are also acccepted.

- rows (string | number; optional):
    Defines the number of rows in a text area.

- size (string; optional):
    Set the size of the Textarea, valid options are 'sm', 'md', or
    'lg'.

- spellCheck (a value equal to: 'true', 'false' | boolean; optional):
    **DEPRECATED** Use `spellcheck` instead  Indicates whether spell
    checking is allowed for the element.

- spellcheck (a value equal to: 'true', 'false' | boolean; optional):
    Indicates whether spell checking is allowed for the element.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- tabIndex (string | number; optional):
    **DEPRECATED** Use `tabindex` instead  Overrides the browser's
    default tab order and follows the one specified instead.

- tabindex (string | number; optional):
    Overrides the browser's default tab order and follows the one
    specified instead.

- title (string; optional):
    Text to be displayed in a tooltip when hovering over the element.

- valid (boolean; optional):
    Apply valid style to the Textarea for feedback purposes. This will
    cause any FormFeedback in the enclosing div with valid=True to
    display.

- value (string; default ''):
    The value of the textarea.

- wrap (string; optional):
    Indicates whether the text should be wrapped."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, key=Component.UNDEFINED, value=Component.UNDEFINED, autofocus=Component.UNDEFINED, autoFocus=Component.UNDEFINED, cols=Component.UNDEFINED, disabled=Component.UNDEFINED, form=Component.UNDEFINED, maxlength=Component.UNDEFINED, maxLength=Component.UNDEFINED, minlength=Component.UNDEFINED, minLength=Component.UNDEFINED, name=Component.UNDEFINED, placeholder=Component.UNDEFINED, readonly=Component.UNDEFINED, readOnly=Component.UNDEFINED, required=Component.UNDEFINED, rows=Component.UNDEFINED, wrap=Component.UNDEFINED, accesskey=Component.UNDEFINED, accessKey=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, contenteditable=Component.UNDEFINED, contentEditable=Component.UNDEFINED, contextmenu=Component.UNDEFINED, contextMenu=Component.UNDEFINED, dir=Component.UNDEFINED, draggable=Component.UNDEFINED, hidden=Component.UNDEFINED, lang=Component.UNDEFINED, spellcheck=Component.UNDEFINED, spellCheck=Component.UNDEFINED, style=Component.UNDEFINED, tabindex=Component.UNDEFINED, tabIndex=Component.UNDEFINED, title=Component.UNDEFINED, size=Component.UNDEFINED, valid=Component.UNDEFINED, invalid=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, n_clicks=Component.UNDEFINED, n_clicks_timestamp=Component.UNDEFINED, debounce=Component.UNDEFINED, loading_state=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'accessKey', 'accesskey', 'autoFocus', 'autofocus', 'className', 'class_name', 'cols', 'contentEditable', 'contenteditable', 'contextMenu', 'contextmenu', 'debounce', 'dir', 'disabled', 'draggable', 'form', 'hidden', 'invalid', 'key', 'lang', 'loading_state', 'maxLength', 'maxlength', 'minLength', 'minlength', 'n_blur', 'n_blur_timestamp', 'n_clicks', 'n_clicks_timestamp', 'n_submit', 'n_submit_timestamp', 'name', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'readOnly', 'readonly', 'required', 'rows', 'size', 'spellCheck', 'spellcheck', 'style', 'tabIndex', 'tabindex', 'title', 'valid', 'value', 'wrap']
        self._type = 'Textarea'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'accessKey', 'accesskey', 'autoFocus', 'autofocus', 'className', 'class_name', 'cols', 'contentEditable', 'contenteditable', 'contextMenu', 'contextmenu', 'debounce', 'dir', 'disabled', 'draggable', 'form', 'hidden', 'invalid', 'key', 'lang', 'loading_state', 'maxLength', 'maxlength', 'minLength', 'minlength', 'n_blur', 'n_blur_timestamp', 'n_clicks', 'n_clicks_timestamp', 'n_submit', 'n_submit_timestamp', 'name', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'readOnly', 'readonly', 'required', 'rows', 'size', 'spellCheck', 'spellcheck', 'style', 'tabIndex', 'tabindex', 'title', 'valid', 'value', 'wrap']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Textarea, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Pagination(Component):
    """A Pagination component.
The container for presentational components for building a pagination UI.
Individual pages should be added as children using the `PaginationItem`
component.

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- active_page (number; default 1):
    The currently active page.

- className (string; optional):
    **DEPRECATED** - Use class_name instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- first_last (boolean; default False):
    When True, this will display a first and last icon at the
    beginning and end of the component.

- fully_expanded (boolean; default True):
    When True, this will display all numbers between `min_value` and
    `max_value`.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- max_value (number; required):
    Maximum (rightmost) value to appear in the pagination. Must be
    defined. If the `min_value` and `step` together cannot reach this
    value, then the next stepped value is used as the maximum.

- min_value (number; default 1):
    Minimum (leftmost) value to appear in the pagination.

- previous_next (boolean; default False):
    When True, this will display a previous and next icon before and
    after the individual page numbers.

- size (a value equal to: 'sm', 'lg'; optional):
    Set the size of all page items in the pagination.

- step (number; default 1):
    Page increment step.

- style (dict; optional):
    Defines CSS styles which will override styles previously set."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, style=Component.UNDEFINED, size=Component.UNDEFINED, min_value=Component.UNDEFINED, max_value=Component.REQUIRED, step=Component.UNDEFINED, active_page=Component.UNDEFINED, fully_expanded=Component.UNDEFINED, previous_next=Component.UNDEFINED, first_last=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'active_page', 'className', 'class_name', 'first_last', 'fully_expanded', 'loading_state', 'max_value', 'min_value', 'previous_next', 'size', 'step', 'style']
        self._type = 'Pagination'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'active_page', 'className', 'class_name', 'first_last', 'fully_expanded', 'loading_state', 'max_value', 'min_value', 'previous_next', 'size', 'step', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['max_value']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Pagination, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class DropdownMenu(Component):
    """A DropdownMenu component.
DropdownMenu creates an overlay useful for grouping together links and other
content to organise navigation or other interactive elements.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- addon_type (boolean | a value equal to: 'prepend', 'append'; optional):
    Set this to 'prepend' or 'append' if the DropdownMenu is being
    used in an input group.

- align_end (boolean; optional):
    Align the DropdownMenu along the right side of its parent.
    Default: False.

- caret (boolean; default True):
    Add a caret to the DropdownMenu toggle. Default: True.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; optional):
    Set the color of the DropdownMenu toggle. Available options are:
    'primary', 'secondary', 'success', 'warning', 'danger', 'info',
    'link' or any valid CSS color of your choice (e.g. a hex code, a
    decimal code or a CSS color name) Default: 'primary'.

- direction (a value equal to: 'down', 'start', 'end', 'up', 'left', 'right', 'end'; optional):
    Direction in which to expand the DropdownMenu. Default: 'down'.
    `left` and `right` have been deprecated, and `start` and `end`
    should be used instead.

- disabled (boolean; default False):
    Disable the dropdown.

- group (boolean; optional):
    Set group to True if the DropdownMenu is inside a ButtonGroup.

- in_navbar (boolean; optional):
    Set this to True if the DropdownMenu is inside a navbar. Default:
    False.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- label (string; optional):
    Label for the DropdownMenu toggle.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- menu_variant (a value equal to: 'light', 'dark'; default 'light'):
    Set `menu_variant=\"dark\"` to create a dark-mode drop down
    instead.

- nav (boolean; optional):
    Set this to True if the DropdownMenu is inside a nav for styling
    consistent with other nav items. Default: False.

- right (boolean; optional):
    **DEPRECATED** Use `align_end` instead.  Align the DropdownMenu
    along the right side of its parent. Default: False.

- size (a value equal to: 'sm', 'md', 'lg'; optional):
    Size of the DropdownMenu. 'sm' corresponds to small, 'md' to
    medium and 'lg' to large.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- toggleClassName (string; optional):
    **DEPRECATED** Use `toggle_class_name` instead.  Often used with
    CSS to style elements with common properties. The classes
    specified with this prop will be applied to the DropdownMenu
    toggle.

- toggle_class_name (string; optional):
    Often used with CSS to style elements with common properties. The
    classes specified with this prop will be applied to the
    DropdownMenu toggle.

- toggle_style (dict; optional):
    Defines CSS styles which will override styles previously set. The
    styles set here apply to the DropdownMenu toggle."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, label=Component.UNDEFINED, direction=Component.UNDEFINED, align_end=Component.UNDEFINED, right=Component.UNDEFINED, in_navbar=Component.UNDEFINED, addon_type=Component.UNDEFINED, disabled=Component.UNDEFINED, nav=Component.UNDEFINED, caret=Component.UNDEFINED, color=Component.UNDEFINED, menu_variant=Component.UNDEFINED, toggle_style=Component.UNDEFINED, toggle_class_name=Component.UNDEFINED, toggleClassName=Component.UNDEFINED, size=Component.UNDEFINED, loading_state=Component.UNDEFINED, group=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'addon_type', 'align_end', 'caret', 'className', 'class_name', 'color', 'direction', 'disabled', 'group', 'in_navbar', 'key', 'label', 'loading_state', 'menu_variant', 'nav', 'right', 'size', 'style', 'toggleClassName', 'toggle_class_name', 'toggle_style']
        self._type = 'DropdownMenu'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'addon_type', 'align_end', 'caret', 'className', 'class_name', 'color', 'direction', 'disabled', 'group', 'in_navbar', 'key', 'label', 'loading_state', 'menu_variant', 'nav', 'right', 'size', 'style', 'toggleClassName', 'toggle_class_name', 'toggle_style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(DropdownMenu, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Input(Component):
    """An Input component.
A basic HTML input control for entering text, numbers, or passwords, with
Bootstrap styles automatically applied. This component is much like its
counterpart in dash_core_components, but with a few additions such as the
`valid` and `invalid` props for providing user feedback.

Note that checkbox and radio types are supported through
the Checklist and RadioItems component. Dates, times, and file uploads
are supported through separate components in other libraries.

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- autoComplete (string; optional):
    **DEPRECATED** Use `autocomplete` instead.  This attribute
    indicates whether the value of the control can be automatically
    completed by the browser.

- autoFocus (a value equal to: 'autoFocus', 'autofocus', 'AUTOFOCUS' | boolean; optional):
    **DEPRECATED** Use `autofocus` instead.  The element should be
    automatically focused after the page loaded. autoFocus is an HTML
    boolean attribute - it is enabled by a boolean or 'autoFocus'.
    Alternative capitalizations `autofocus` & `AUTOFOCUS` are also
    acccepted.

- autocomplete (string; optional):
    This attribute indicates whether the value of the control can be
    automatically completed by the browser.

- autofocus (a value equal to: 'autoFocus', 'autofocus', 'AUTOFOCUS' | boolean; optional):
    The element should be automatically focused after the page loaded.
    autoFocus is an HTML boolean attribute - it is enabled by a
    boolean or 'autoFocus'. Alternative capitalizations `autofocus` &
    `AUTOFOCUS` are also acccepted.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- debounce (boolean; default False):
    If True, changes to input will be sent back to the Dash server
    only when the enter key is pressed or when the component loses
    focus.  If it's False, it will sent the value back on every
    change.

- disabled (boolean; optional):
    Set to True to disable the Input.

- html_size (string; optional):
    The initial size of the control. This value is in pixels unless
    the value of the type attribute is text or password, in which case
    it is an integer number of characters. This attribute applies only
    when the type attribute is set to text, search, tel, url, email,
    or password, otherwise it is ignored. In addition, the size must
    be greater than zero. If you do not specify a size, a default
    value of 20 is used.

- inputMode (a value equal to: "verbatim", "latin", "latin-name", "latin-prose", "full-width-latin", "kana", "katakana", "numeric", "tel", "email", "url"; optional):
    **DEPRECATED** Use `inputmode` instead.  Provides a hint to the
    browser as to the type of data that might be entered by the user
    while editing the element or its contents.

- inputmode (a value equal to: "verbatim", "latin", "latin-name", "latin-prose", "full-width-latin", "kana", "katakana", "numeric", "tel", "email", "url"; optional):
    Provides a hint to the browser as to the type of data that might
    be entered by the user while editing the element or its contents.

- invalid (boolean; optional):
    Apply invalid style to the Input for feedback purposes. This will
    cause any FormFeedback in the enclosing div with valid=False to
    display.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- list (string; optional):
    Identifies a list of pre-defined options to suggest to the user.
    The value must be the id of a <datalist> element in the same
    document. The browser displays only options that are valid values
    for this input element. This attribute is ignored when the type
    attribute's value is hidden, checkbox, radio, file, or a button
    type.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- max (string | number; optional):
    The maximum (numeric or date-time) value for this item, which must
    not be less than its minimum (min attribute) value.

- maxLength (string | number; optional):
    **DEPRECATED** Use `maxlength` instead.  If the value of the type
    attribute is text, email, search, password, tel, or url, this
    attribute specifies the maximum number of characters (in UTF-16
    code units) that the user can enter. For other control types, it
    is ignored. It can exceed the value of the size attribute. If it
    is not specified, the user can enter an unlimited number of
    characters. Specifying a negative number results in the default
    behavior (i.e. the user can enter an unlimited number of
    characters). The constraint is evaluated only when the value of
    the attribute has been changed.

- maxlength (string | number; optional):
    If the value of the type attribute is text, email, search,
    password, tel, or url, this attribute specifies the maximum number
    of characters (in UTF-16 code units) that the user can enter. For
    other control types, it is ignored. It can exceed the value of the
    size attribute. If it is not specified, the user can enter an
    unlimited number of characters. Specifying a negative number
    results in the default behavior (i.e. the user can enter an
    unlimited number of characters). The constraint is evaluated only
    when the value of the attribute has been changed.

- min (string | number; optional):
    The minimum (numeric or date-time) value for this item, which must
    not be greater than its maximum (max attribute) value.

- minLength (string | number; optional):
    **DEPRECATED** Use `minlength` instead.  If the value of the type
    attribute is text, email, search, password, tel, or url, this
    attribute specifies the minimum number of characters (in Unicode
    code points) that the user can enter. For other control types, it
    is ignored.

- minlength (string | number; optional):
    If the value of the type attribute is text, email, search,
    password, tel, or url, this attribute specifies the minimum number
    of characters (in Unicode code points) that the user can enter.
    For other control types, it is ignored.

- n_blur (number; default 0):
    Number of times the input lost focus.

- n_blur_timestamp (number; default -1):
    Last time the input lost focus.

- n_submit (number; default 0):
    Number of times the `Enter` key was pressed while the input had
    focus.

- n_submit_timestamp (number; default -1):
    Last time that `Enter` was pressed.

- name (string; optional):
    The name of the control, which is submitted with the form data.

- pattern (string; optional):
    A regular expression that the control's value is checked against.
    The pattern must match the entire value, not just some subset. Use
    the title attribute to describe the pattern to help the user. This
    attribute applies when the value of the type attribute is text,
    search, tel, url, email, or password, otherwise it is ignored. The
    regular expression language is the same as JavaScript RegExp
    algorithm, with the 'u' parameter that makes it treat the pattern
    as a sequence of unicode code points. The pattern is not
    surrounded by forward slashes.

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- placeholder (string | number; optional):
    A hint to the user of what can be entered in the control . The
    placeholder text must not contain carriage returns or line-feeds.
    Note: Do not use the placeholder attribute instead of a <label>
    element, their purposes are different. The <label> attribute
    describes the role of the form element (i.e. it indicates what
    kind of information is expected), and the placeholder attribute is
    a hint about the format that the content should take. There are
    cases in which the placeholder attribute is never displayed to the
    user, so the form must be understandable without it.

- plaintext (boolean; optional):
    Set to True for an input styled as plain text with the default
    form field styling removed and the correct margins and padding
    preserved. Typically you will want to use this in conjunction with
    readonly=True.

- readonly (boolean | a value equal to: 'readOnly', 'readonly', 'READONLY'; optional):
    Indicates whether the element can be edited.

- required (a value equal to: 'required', 'REQUIRED' | boolean; optional):
    This attribute specifies that the user must fill in a value before
    submitting a form. It cannot be used when the type attribute is
    hidden, image, or a button type (submit, reset, or button). The
    :optional and :required CSS pseudo-classes will be applied to the
    field as appropriate. required is an HTML boolean attribute - it
    is enabled by a boolean or 'required'. Alternative capitalizations
    `REQUIRED` are also acccepted.

- size (string; optional):
    Set the size of the Input. Options: 'sm' (small), 'md' (medium) or
    'lg' (large). Default is 'md'.

- step (string | number; default 'any'):
    Works with the min and max attributes to limit the increments at
    which a numeric or date-time value can be set. It can be the
    string any or a positive floating point number. If this attribute
    is not set to any, the control accepts only values at multiples of
    the step value greater than the minimum.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- tabIndex (string; optional):
    **DEPRECATED** Use `tabindex` instead.  Overrides the browser's
    default tab order and follows the one specified instead.

- tabindex (string; optional):
    Overrides the browser's default tab order and follows the one
    specified instead.

- type (a value equal to: "text", 'number', 'password', 'email', 'range', 'search', 'tel', 'url', 'hidden'; optional):
    The type of control to render.

- valid (boolean; optional):
    Apply valid style to the Input for feedback purposes. This will
    cause any FormFeedback in the enclosing div with valid=True to
    display.

- value (string | number; optional):
    The value of the Input."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, type=Component.UNDEFINED, value=Component.UNDEFINED, disabled=Component.UNDEFINED, autocomplete=Component.UNDEFINED, autoComplete=Component.UNDEFINED, autofocus=Component.UNDEFINED, autoFocus=Component.UNDEFINED, inputmode=Component.UNDEFINED, inputMode=Component.UNDEFINED, list=Component.UNDEFINED, max=Component.UNDEFINED, maxlength=Component.UNDEFINED, maxLength=Component.UNDEFINED, min=Component.UNDEFINED, minlength=Component.UNDEFINED, minLength=Component.UNDEFINED, step=Component.UNDEFINED, html_size=Component.UNDEFINED, size=Component.UNDEFINED, valid=Component.UNDEFINED, invalid=Component.UNDEFINED, required=Component.UNDEFINED, plaintext=Component.UNDEFINED, readonly=Component.UNDEFINED, placeholder=Component.UNDEFINED, name=Component.UNDEFINED, pattern=Component.UNDEFINED, n_submit=Component.UNDEFINED, n_submit_timestamp=Component.UNDEFINED, n_blur=Component.UNDEFINED, n_blur_timestamp=Component.UNDEFINED, debounce=Component.UNDEFINED, loading_state=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, tabindex=Component.UNDEFINED, tabIndex=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'autoComplete', 'autoFocus', 'autocomplete', 'autofocus', 'className', 'class_name', 'debounce', 'disabled', 'html_size', 'inputMode', 'inputmode', 'invalid', 'key', 'list', 'loading_state', 'max', 'maxLength', 'maxlength', 'min', 'minLength', 'minlength', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'name', 'pattern', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'plaintext', 'readonly', 'required', 'size', 'step', 'style', 'tabIndex', 'tabindex', 'type', 'valid', 'value']
        self._type = 'Input'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'autoComplete', 'autoFocus', 'autocomplete', 'autofocus', 'className', 'class_name', 'debounce', 'disabled', 'html_size', 'inputMode', 'inputmode', 'invalid', 'key', 'list', 'loading_state', 'max', 'maxLength', 'maxlength', 'min', 'minLength', 'minlength', 'n_blur', 'n_blur_timestamp', 'n_submit', 'n_submit_timestamp', 'name', 'pattern', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'plaintext', 'readonly', 'required', 'size', 'step', 'style', 'tabIndex', 'tabindex', 'type', 'valid', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Input, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class NavbarSimple(Component):
    """A NavbarSimple component.
A self-contained navbar ready for use. If you need more customisability try
`Navbar` instead.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- brand (string; optional):
    Brand text, to go top left of the navbar.

- brand_external_link (boolean; optional):
    If True, the browser will treat the brand link as external,
    forcing a page refresh at the new location. If False, this just
    changes the location without triggering a page refresh. Use this
    if you are observing dcc.Location, for instance. Defaults to True
    for absolute URLs and False otherwise.

- brand_href (string; optional):
    Link to attach to brand.

- brand_style (dict; optional):
    CSS style options for brand.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- color (string; default 'light'):
    Sets the color of the NavbarSimple. Main options are primary,
    light and dark, default light.  You can also choose one of the
    other contextual classes provided by Bootstrap (secondary,
    success, warning, danger, info, white) or any valid CSS color of
    your choice (e.g. a hex code, a decimal code or a CSS color name).

- dark (boolean; optional):
    Applies the `navbar-dark` class to the NavbarSimple, causing text
    in the children of the Navbar to use light colors for contrast /
    visibility.

- expand (boolean | string; default 'md'):
    Specify breakpoint at which to expand the menu bar. Options are:
    'xs', 'sm', 'md', 'lg', or 'xl'. Below this breakpoint the navbar
    will collapse and navitems will be placed in a togglable collapse
    element.

- fixed (string; optional):
    Fix the navbar's position at the top or bottom of the page,
    options: top, bottom.

- fluid (boolean; default False):
    The contents of the Navbar are wrapped in a container, use
    fluid=True to make this container fluid, so that in particular,
    the contents of the navbar fill the available horizontal space.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- light (boolean; default True):
    Applies the `navbar-light` class to the NavbarSimple, causing text
    in the children of the Navbar to use dark colors for contrast /
    visibility.

- links_left (boolean; default False):
    Align the navlinks in the navbar to the left. Default: False.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- sticky (string; optional):
    Stick the navbar to the top or the bottom of the viewport,
    options: top, bottom  With `sticky`, the navbar remains in the
    viewport when you scroll. By contrast, with `fixed`, the navbar
    will remain at the top or bottom of the page.

- style (dict; optional):
    Defines CSS styles which will override styles previously set."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, brand=Component.UNDEFINED, brand_href=Component.UNDEFINED, brand_style=Component.UNDEFINED, brand_external_link=Component.UNDEFINED, fluid=Component.UNDEFINED, links_left=Component.UNDEFINED, light=Component.UNDEFINED, dark=Component.UNDEFINED, fixed=Component.UNDEFINED, sticky=Component.UNDEFINED, color=Component.UNDEFINED, expand=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'brand', 'brand_external_link', 'brand_href', 'brand_style', 'className', 'class_name', 'color', 'dark', 'expand', 'fixed', 'fluid', 'key', 'light', 'links_left', 'loading_state', 'sticky', 'style']
        self._type = 'NavbarSimple'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'brand', 'brand_external_link', 'brand_href', 'brand_style', 'className', 'class_name', 'color', 'dark', 'expand', 'fixed', 'fluid', 'key', 'light', 'links_left', 'loading_state', 'sticky', 'style']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(NavbarSimple, self).__init__(children=children, **args)



import io
import os

from setuptools import find_packages, setup

HERE = os.path.dirname(os.path.abspath(__file__))

GITHUB_URL = "https://github.com/facultyai/dash-bootstrap-components/"


def _get_version():
    """ Get version by parsing _version programmatically """
    version_ns = {}
    with open(
        os.path.join(HERE, "dash_bootstrap_components", "_version.py")
    ) as f:
        exec(f.read(), {}, version_ns)
    version = version_ns["__version__"]
    return version


def _get_long_description():
    with io.open(os.path.join(HERE, "landing-page.md"), encoding="utf8") as f:
        return f.read()


setup(
    name="dash-bootstrap-components",
    version=_get_version(),
    description="Bootstrap themed components for use in Plotly Dash",
    long_description=_get_long_description(),
    long_description_content_type="text/markdown",
    license="Apache Software License",
    author="Faculty",
    author_email="opensource@faculty.ai",
    url="https://dash-bootstrap-components.opensource.faculty.ai/",
    project_urls={
        "Bug Reports": os.path.join(GITHUB_URL, "issues"),
        "Source": GITHUB_URL,
    },
    packages=find_packages(),
    install_requires=["dash>=2.0.0"],
    include_package_data=True,
    classifiers=[
        "Framework :: Dash",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    extras_require={"pandas": ["numpy", "pandas"]},
    python_requires=">=3.6, <4",
)



"""Bootstrap themed components for use in Plotly Dash"""
import os
import sys

from dash_bootstrap_components import _components, icons, themes
from dash_bootstrap_components._components import *  # noqa
from dash_bootstrap_components._table import _generate_table_from_df
from dash_bootstrap_components._version import __version__

__all__ = _components.__all__ + ["icons", "themes"]

_current_path = os.path.dirname(os.path.abspath(__file__))
_METADATA_PATH = os.path.join(_current_path, "_components", "metadata.json")

_js_dist = [
    {
        "relative_package_path": (
            "_components/dash_bootstrap_components.min.js"
        ),
        "external_url": (
            f"https://unpkg.com/dash-bootstrap-components@{__version__}"
            "/dist/dash_bootstrap_components.min.js"
        ),
        "namespace": "dash_bootstrap_components",
    }
]

_css_dist = []


for _component_name in _components.__all__:
    _component = getattr(_components, _component_name)
    _component._js_dist = _js_dist
    _component._css_dist = _css_dist


sys.modules[__name__].Table.from_dataframe = classmethod(
    _generate_table_from_df
)


# TODO: when Python 3.6 support is dropped we can simplify this with PEP 562
# https://www.python.org/dev/peps/pep-0562/
class _V1DeprecationWarningWrapper:
    def __init__(self, wrapped, deprecated):
        self.wrapped = wrapped
        self.deprecated = deprecated

    def __getattr__(self, name):
        if name in self.deprecated:
            raise AttributeError(
                f"{name} was deprecated in dash-bootstrap-components version "
                f"1.0.0. You are using {__version__}. For more details please "
                "see the migration guide: "
                "https://dash-bootstrap-components.opensource.faculty.ai/"
                "migration-guide/"
            )
        return getattr(self.wrapped, name)

    def __dir__(self):
        # required for autocomplete. filter out os, and sys imports
        return [
            item
            for item in self.wrapped.__dir__()
            if item not in {"os", "sys"}
        ]


sys.modules[__name__] = _V1DeprecationWarningWrapper(
    sys.modules[__name__],
    [
        "CardColumns",
        "CardDeck",
        "FormGroup",
        "InputGroupAddon",
        "Jumbotron",
        "ListGroupItemHeading",
        "ListGroupItemText",
    ],
)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Popover(Component):
    """A Popover component.
Popover creates a toggleable overlay that can be used to provide additional
information or content to users without having to load a new page or open a
new window.

Use the `PopoverHeader` and `PopoverBody` components to control the layout
of the children.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- autohide (boolean; default False):
    Optionally hide popover when hovering over content - default
    False.

- body (boolean; optional):
    When body is `True`, the Popover will render all children in a
    `PopoverBody` automatically.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- delay (dict; default {show: 0, hide: 50}):
    Optionally override show/hide delays.

    `delay` is a dict with keys:

    - hide (number; optional)

    - show (number; optional) | number

- flip (boolean; default True):
    Whether to flip the direction of the popover if too close to the
    container edge, default True.

- hide_arrow (boolean; optional):
    Hide popover arrow.

- innerClassName (string; optional):
    **DEPRECATED** Use `inner_class_name` instead.  CSS class to apply
    to the popover.

- inner_class_name (string; optional):
    CSS class to apply to the popover.

- is_open (boolean; optional):
    Whether the Popover is open or not.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- offset (string | number; optional):
    Offset of the popover relative to its target. The offset can be
    passed as a comma separated pair of values e.g. \"0,8\", where the
    first number, skidding, displaces the popover along the reference
    element. The second number, distance, displaces the popover away
    from, or toward, the reference element in the direction of its
    placement. A positive number displaces it further away, while a
    negative number lets it overlap the reference. See
    https://popper.js.org/docs/v2/modifiers/offset/ for more info.
    Alternatively, you can provide just a single 'distance' number
    e.g. 8 to displace it horizontally.

- placement (a value equal to: 'auto', 'auto-start', 'auto-end', 'top', 'top-start', 'top-end', 'right', 'right-start', 'right-end', 'bottom', 'bottom-start', 'bottom-end', 'left', 'left-start', 'left-end'; default 'right'):
    Specify popover placement.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- target (string | dict; optional):
    ID of the component to attach the popover to.

- trigger (string; optional):
    Space separated list of triggers (e.g. \"click hover focus
    legacy\"). These specify ways in which the target component can
    toggle the popover. If not specified you must toggle the popover
    yourself using callbacks. Options are: - \"click\": toggles the
    popover when the target is clicked. - \"hover\": toggles the
    popover when the target is hovered over with the cursor. -
    \"focus\": toggles the popover when the target receives focus -
    \"legacy\": toggles the popover when the target is clicked, but
    will also dismiss the popover when the user clicks outside of the
    popover."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, placement=Component.UNDEFINED, target=Component.UNDEFINED, trigger=Component.UNDEFINED, is_open=Component.UNDEFINED, hide_arrow=Component.UNDEFINED, inner_class_name=Component.UNDEFINED, innerClassName=Component.UNDEFINED, delay=Component.UNDEFINED, offset=Component.UNDEFINED, flip=Component.UNDEFINED, body=Component.UNDEFINED, autohide=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'autohide', 'body', 'className', 'class_name', 'delay', 'flip', 'hide_arrow', 'innerClassName', 'inner_class_name', 'is_open', 'key', 'loading_state', 'offset', 'placement', 'style', 'target', 'trigger']
        self._type = 'Popover'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'autohide', 'body', 'className', 'class_name', 'delay', 'flip', 'hide_arrow', 'innerClassName', 'inner_class_name', 'is_open', 'key', 'loading_state', 'offset', 'placement', 'style', 'target', 'trigger']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Popover, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Col(Component):
    """A Col component.
Component for creating Bootstrap columns to control the layout of your page.

Use the width argument to specify width, or use the breakpoint arguments
(xs, sm, md, lg, xl) to control the width of the columns on different screen
sizes to achieve a responsive layout.

Keyword arguments:

- children (a list of or a singular dash component, string or number; optional):
    The children of this component.

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- align (a value equal to: 'start', 'center', 'end', 'stretch', 'baseline'; optional):
    Set vertical alignment of this column's content in the parent row.
    Options are 'start', 'center', 'end', 'stretch', 'baseline'.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- lg (optional):
    Specify column behaviour on a large screen.  Valid arguments are
    boolean, an integer in the range 1-12 inclusive, or a dictionary
    with keys 'offset', 'order', 'size'. See the documentation for
    more details.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- md (optional):
    Specify column behaviour on a medium screen.  Valid arguments are
    boolean, an integer in the range 1-12 inclusive, or a dictionary
    with keys 'offset', 'order', 'size'. See the documentation for
    more details.

- sm (optional):
    Specify column behaviour on a small screen.  Valid arguments are
    boolean, an integer in the range 1-12 inclusive, or a dictionary
    with keys 'offset', 'order', 'size'. See the documentation for
    more details.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- width (optional):
    Specify the width of the column. Behind the scenes this sets
    behaviour at the xs breakpoint, and will be overriden if xs is
    specified.  Valid arguments are boolean, an integer in the range
    1-12 inclusive, or a dictionary with keys 'offset', 'order',
    'size'. See the documentation for more details.

- xl (optional):
    Specify column behaviour on an extra large screen.  Valid
    arguments are boolean, an integer in the range 1-12 inclusive, or
    a dictionary with keys 'offset', 'order', 'size'. See the
    documentation for more details.

- xs (optional):
    Specify column behaviour on an extra small screen.  Valid
    arguments are boolean, an integer in the range 1-12 inclusive, or
    a dictionary with keys 'offset', 'order', 'size'. See the
    documentation for more details.

- xxl (optional):
    Specify column behaviour on an extra extra large screen.  Valid
    arguments are boolean, an integer in the range 1-12 inclusive, or
    a dictionary with keys 'offset', 'order', 'size'. See the
    documentation for more details."""
    @_explicitize_args
    def __init__(self, children=None, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, width=Component.UNDEFINED, xs=Component.UNDEFINED, sm=Component.UNDEFINED, md=Component.UNDEFINED, lg=Component.UNDEFINED, xl=Component.UNDEFINED, xxl=Component.UNDEFINED, align=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['children', 'id', 'align', 'className', 'class_name', 'key', 'lg', 'loading_state', 'md', 'sm', 'style', 'width', 'xl', 'xs', 'xxl']
        self._type = 'Col'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['children', 'id', 'align', 'className', 'class_name', 'key', 'lg', 'loading_state', 'md', 'sm', 'style', 'width', 'xl', 'xs', 'xxl']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Col, self).__init__(children=children, **args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Select(Component):
    """A Select component.
Create a HTML select element with Bootstrap styles. Specify options as a
list of dictionaries with keys label, value and disabled.

Keyword arguments:

- id (string; optional):
    The ID of this component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  Often used with CSS to
    style elements with common properties.

- class_name (string; optional):
    Often used with CSS to style elements with common properties.

- disabled (boolean; optional):
    Set to True to disable the Select.

- html_size (string; optional):
    This represents the number of rows in the select that should be
    visible at one time. It will result in the Select being rendered
    as a scrolling list box rather than a dropdown.

- invalid (boolean; optional):
    Apply invalid style to the Input for feedback purposes. This will
    cause any FormFeedback in the enclosing div with valid=False to
    display.

- key (string; optional):
    A unique identifier for the component, used to improve performance
    by React.js while rendering components See
    https://reactjs.org/docs/lists-and-keys.html for more info.

- name (string; optional):
    The name of the control, which is submitted with the form data.

- options (list of dicts; optional):
    An array of options for the select.

    `options` is a list of dicts with keys:

    - disabled (boolean; optional):
        If True, this checkbox is disabled and can't be clicked on.

    - label (string | number; required):
        The options's label.

    - title (string; optional):
        The HTML 'title' attribute for the option. Allows for
        information on hover. For more information on this attribute,
        see
        https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/title.

    - value (string; required):
        The value of the option. This value corresponds to the items
        specified in the `value` property.

- persisted_props (list of a value equal to: 'value's; default ['value']):
    Properties whose user interactions will persist after refreshing
    the component or the page. Since only `value` is allowed this prop
    can normally be ignored.

- persistence (boolean | string | number; optional):
    Used to allow user interactions in this component to be persisted
    when the component - or the page - is refreshed. If `persisted` is
    truthy and hasn't changed from its previous value, a `value` that
    the user has changed while using the app will keep that change, as
    long as the new `value` also matches what was given originally.
    Used in conjunction with `persistence_type`.

- persistence_type (a value equal to: 'local', 'session', 'memory'; default 'local'):
    Where persisted user changes will be stored: memory: only kept in
    memory, reset on page refresh. local: window.localStorage, data is
    kept after the browser quit. session: window.sessionStorage, data
    is cleared once the browser quit.

- placeholder (string; default ''):
    Placeholder text to display before a selection is made.

- required (a value equal to: 'required', 'REQUIRED' | boolean; optional):
    This attribute specifies that the user must fill in a value before
    submitting a form. It cannot be used when the type attribute is
    hidden, image, or a button type (submit, reset, or button). The
    :optional and :required CSS pseudo-classes will be applied to the
    field as appropriate. required is an HTML boolean attribute - it
    is enabled by a boolean or 'required'. Alternative capitalizations
    `REQUIRED` are also acccepted.

- size (string; optional):
    Set the size of the Input. Options: 'sm' (small), 'md' (medium) or
    'lg' (large). Default is 'md'.

- style (dict; optional):
    Defines CSS styles which will override styles previously set.

- valid (boolean; optional):
    Apply valid style to the Input for feedback purposes. This will
    cause any FormFeedback in the enclosing div with valid=True to
    display.

- value (string | number; default ''):
    The value of the currently selected option."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, key=Component.UNDEFINED, placeholder=Component.UNDEFINED, value=Component.UNDEFINED, options=Component.UNDEFINED, disabled=Component.UNDEFINED, required=Component.UNDEFINED, valid=Component.UNDEFINED, invalid=Component.UNDEFINED, size=Component.UNDEFINED, html_size=Component.UNDEFINED, persistence=Component.UNDEFINED, persisted_props=Component.UNDEFINED, persistence_type=Component.UNDEFINED, name=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'className', 'class_name', 'disabled', 'html_size', 'invalid', 'key', 'name', 'options', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'required', 'size', 'style', 'valid', 'value']
        self._type = 'Select'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'className', 'class_name', 'disabled', 'html_size', 'invalid', 'key', 'name', 'options', 'persisted_props', 'persistence', 'persistence_type', 'placeholder', 'required', 'size', 'style', 'valid', 'value']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in []:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Select, self).__init__(**args)



# AUTO GENERATED FILE - DO NOT EDIT

from dash.development.base_component import Component, _explicitize_args


class Carousel(Component):
    """A Carousel component.
Component for creating Bootstrap carousel.  This component is a slideshow
for cycling through a series of content.

Keyword arguments:

- id (string; optional):
    The ID of the component, used to identify dash components in
    callbacks. The ID needs to be unique across all of the components
    in an app.

- active_index (number; default 0):
    The current visible slide number.

- className (string; optional):
    **DEPRECATED** Use `class_name` instead.  efines the className of
    the carousel container. Often used with CSS to style elements with
    common properties.

- class_name (string; optional):
    Defines the className of the carousel container. Often used with
    CSS to style elements with common properties.

- controls (boolean; default True):
    Show the Carousel previous and next arrows for changing the
    current slide.

- indicators (boolean; default True):
    Show a set of slide position indicators.

- interval (number; optional):
    the interval at which the carousel automatically cycles (default:
    5000) If set to None, carousel will not Autoplay (i.e. will not
    automatically cycle).

- items (list of dicts; required):
    The items to display on the slides in the carousel.

    `items` is a list of dicts with keys:

    - alt (string; optional):
        The alternate text for an image, if the image cannot be
        displayed.

    - caption (string; optional):
        The caption of the item.  The text is displayed in a <p>
        element.

    - captionClassName (string; optional):
        **DEPRECATED** Use `caption_class_name` instead.  The class
        name for the header and caption container.

    - caption_class_name (string; optional):
        The class name for the header and caption container.

    - header (string; optional):
        The header of the text on the slide. It is displayed in a <h5>
        element.

    - imgClassName (string; optional):
        **DEPRECATED** Use `img_class_name` instead.  The className
        for the image.  The default is 'd-block w-100'.

    - img_class_name (string; optional):
        The className for the image.  The default is 'd-block w-100'.

    - img_style (dict; optional):
        The style for the image.

    - key (string; optional):
        A unique identifier for the slide, used to improve performance
        by React.js while rendering components See
        https://reactjs.org/docs/lists-and-keys.html for more info.

    - src (string; optional):
        The URL of the image.

- loading_state (dict; optional):
    Object that holds the loading state object coming from
    dash-renderer.

    `loading_state` is a dict with keys:

    - component_name (string; optional):
        Holds the name of the component that is loading.

    - is_loading (boolean; optional):
        Determines if the component is loading or not.

    - prop_name (string; optional):
        Holds which property is loading.

- ride (a value equal to: 'carousel'; optional):
    Autoplays the carousel after the user manually cycles the first
    item. If \"carousel\", autoplays the carousel on load.

- slide (boolean; optional):
    controls whether the slide animation on the Carousel works or not.

- style (dict; optional):
    Defines CSS styles of the carousel container. Will override styles
    previously set.

- variant (a value equal to: 'dark'; optional):
    Add `variant=\"dark\"` to the Carousel for darker controls,
    indicators, and captions."""
    @_explicitize_args
    def __init__(self, id=Component.UNDEFINED, style=Component.UNDEFINED, class_name=Component.UNDEFINED, className=Component.UNDEFINED, items=Component.REQUIRED, active_index=Component.UNDEFINED, controls=Component.UNDEFINED, indicators=Component.UNDEFINED, ride=Component.UNDEFINED, slide=Component.UNDEFINED, variant=Component.UNDEFINED, interval=Component.UNDEFINED, loading_state=Component.UNDEFINED, **kwargs):
        self._prop_names = ['id', 'active_index', 'className', 'class_name', 'controls', 'indicators', 'interval', 'items', 'loading_state', 'ride', 'slide', 'style', 'variant']
        self._type = 'Carousel'
        self._namespace = 'dash_bootstrap_components'
        self._valid_wildcard_attributes =            []
        self.available_properties = ['id', 'active_index', 'className', 'class_name', 'controls', 'indicators', 'interval', 'items', 'loading_state', 'ride', 'slide', 'style', 'variant']
        self.available_wildcard_properties =            []
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}
        for k in ['items']:
            if k not in args:
                raise TypeError(
                    'Required argument `' + k + '` was not specified.')
        super(Carousel, self).__init__(**args)
